CalculateAbsorptionForcesSystem

Struct CalculateAbsorptionForcesSystem 

pub struct CalculateAbsorptionForcesSystem<T, const N: usize>(/* private fields */)
where
    T: TransitionComponent;
This sytem calculates the forces from absorbing photons from the CoolingLight entities.

The system assumes that the ActualPhotonsScatteredVector for each atom s already populated with the correct terms. Furthermore, it is assumed that a CoolingLightIndex is present and assigned for all cooling lasers, with an index corresponding to the entries in the ActualPhotonsScatteredVector vector.